Module apisecurity_operations_api

Module apisecurity_operations_api 

Structs

ApiSecurityBulkAddTagsToOperationsParams
struct for passing parameters to the method api_security_bulk_add_tags_to_operations
ApiSecurityBulkCreateOperationsParams
struct for passing parameters to the method api_security_bulk_create_operations
ApiSecurityBulkDeleteOperationsParams
struct for passing parameters to the method api_security_bulk_delete_operations
ApiSecurityCreateOperationParams
struct for passing parameters to the method api_security_create_operation
ApiSecurityCreateOperationTagParams
struct for passing parameters to the method api_security_create_operation_tag
ApiSecurityDeleteOperationParams
struct for passing parameters to the method api_security_delete_operation
ApiSecurityDeleteOperationTagParams
struct for passing parameters to the method api_security_delete_operation_tag
ApiSecurityGetOperationParams
struct for passing parameters to the method api_security_get_operation
ApiSecurityGetOperationTagParams
struct for passing parameters to the method api_security_get_operation_tag
ApiSecurityListDiscoveredOperationsParams
struct for passing parameters to the method api_security_list_discovered_operations
ApiSecurityListOperationTagsParams
struct for passing parameters to the method api_security_list_operation_tags
ApiSecurityListOperationsParams
struct for passing parameters to the method api_security_list_operations
ApiSecurityUpdateOperationParams
struct for passing parameters to the method api_security_update_operation
ApiSecurityUpdateOperationTagParams
struct for passing parameters to the method api_security_update_operation_tag

Enums

ApiSecurityBulkAddTagsToOperationsError
struct for typed errors of method api_security_bulk_add_tags_to_operations
ApiSecurityBulkCreateOperationsError
struct for typed errors of method api_security_bulk_create_operations
ApiSecurityBulkDeleteOperationsError
struct for typed errors of method api_security_bulk_delete_operations
ApiSecurityCreateOperationError
struct for typed errors of method api_security_create_operation
ApiSecurityCreateOperationTagError
struct for typed errors of method api_security_create_operation_tag
ApiSecurityDeleteOperationError
struct for typed errors of method api_security_delete_operation
ApiSecurityDeleteOperationTagError
struct for typed errors of method api_security_delete_operation_tag
ApiSecurityGetOperationError
struct for typed errors of method api_security_get_operation
ApiSecurityGetOperationTagError
struct for typed errors of method api_security_get_operation_tag
ApiSecurityListDiscoveredOperationsError
struct for typed errors of method api_security_list_discovered_operations
ApiSecurityListOperationTagsError
struct for typed errors of method api_security_list_operation_tags
ApiSecurityListOperationsError
struct for typed errors of method api_security_list_operations
ApiSecurityUpdateOperationError
struct for typed errors of method api_security_update_operation
ApiSecurityUpdateOperationTagError
struct for typed errors of method api_security_update_operation_tag

Functions

api_security_bulk_add_tags_to_operations
Add tags to multiple operations in a single request.
api_security_bulk_create_operations
Create multiple operations associated with a specific service in a single request.
api_security_bulk_delete_operations
Delete multiple operations in a single request.
api_security_create_operation
Create a new operation associated with a specific service.
api_security_create_operation_tag
Create a new operation tag associated with a specific service.
api_security_delete_operation
Delete an existing operation associated with a specific service.
api_security_delete_operation_tag
Delete an existing operation tag.
api_security_get_operation
Get a specific operation associated with a service.
api_security_get_operation_tag
Get a specific operation tag by its unique identifier.
api_security_list_discovered_operations
List all discovered operations associated with a specific service. Optionally filter operations by status.
api_security_list_operation_tags
List all operation tags associated with a specific service.
api_security_list_operations
List all operations associated with a specific service. Optionally filter operations by tag ID.
api_security_update_operation
Partially update an existing operation associated with a specific service.
api_security_update_operation_tag
Partially update an existing operation tag.