pub struct ApiSecurityListOperationsParams {
pub service_id: String,
pub tag_id: Option<String>,
pub limit: Option<i32>,
pub page: Option<i32>,
}Expand description
struct for passing parameters to the method api_security_list_operations
Fields
service_id: StringThe unique identifier of the service.
tag_id: Option<String>Filter operations by operation tag ID. Only operations associated with this operation tag will be returned.
limit: Option<i32>The maximum number of operations to return per page.
page: Option<i32>The page number to return.