Module client_side_protection_api

Module client_side_protection_api 

Structs

CspCreatePageParams
struct for passing parameters to the method csp_create_page
CspCreatePolicyParams
struct for passing parameters to the method csp_create_policy
CspCreateWebsiteParams
struct for passing parameters to the method csp_create_website
CspDeletePageParams
struct for passing parameters to the method csp_delete_page
CspDeleteWebsiteParams
struct for passing parameters to the method csp_delete_website
CspGetPageParams
struct for passing parameters to the method csp_get_page
CspGetPolicyParams
struct for passing parameters to the method csp_get_policy
CspGetScriptParams
struct for passing parameters to the method csp_get_script
CspGetWebsiteParams
struct for passing parameters to the method csp_get_website
CspListHeaderEventsParams
struct for passing parameters to the method csp_list_header_events
CspListHeadersParams
struct for passing parameters to the method csp_list_headers
CspListPagesParams
struct for passing parameters to the method csp_list_pages
CspListPoliciesParams
struct for passing parameters to the method csp_list_policies
CspListPolicyReportsParams
struct for passing parameters to the method csp_list_policy_reports
CspListScriptsParams
struct for passing parameters to the method csp_list_scripts
CspListWebsitesParams
struct for passing parameters to the method csp_list_websites
CspUpdatePageParams
struct for passing parameters to the method csp_update_page
CspUpdatePolicyParams
struct for passing parameters to the method csp_update_policy
CspUpdateScriptParams
struct for passing parameters to the method csp_update_script
CspUpdateWebsiteParams
struct for passing parameters to the method csp_update_website

Enums

CspCreatePageError
struct for typed errors of method csp_create_page
CspCreatePolicyError
struct for typed errors of method csp_create_policy
CspCreateWebsiteError
struct for typed errors of method csp_create_website
CspDeletePageError
struct for typed errors of method csp_delete_page
CspDeleteWebsiteError
struct for typed errors of method csp_delete_website
CspGetPageError
struct for typed errors of method csp_get_page
CspGetPolicyError
struct for typed errors of method csp_get_policy
CspGetScriptError
struct for typed errors of method csp_get_script
CspGetWebsiteError
struct for typed errors of method csp_get_website
CspListHeaderEventsError
struct for typed errors of method csp_list_header_events
CspListHeadersError
struct for typed errors of method csp_list_headers
CspListPagesError
struct for typed errors of method csp_list_pages
CspListPoliciesError
struct for typed errors of method csp_list_policies
CspListPolicyReportsError
struct for typed errors of method csp_list_policy_reports
CspListScriptsError
struct for typed errors of method csp_list_scripts
CspListWebsitesError
struct for typed errors of method csp_list_websites
CspUpdatePageError
struct for typed errors of method csp_update_page
CspUpdatePolicyError
struct for typed errors of method csp_update_policy
CspUpdateScriptError
struct for typed errors of method csp_update_script
CspUpdateWebsiteError
struct for typed errors of method csp_update_website

Functions

csp_create_page
Create a new page for monitoring.
csp_create_policy
Create a new Content Security Policy for a page.
csp_create_website
Create a new website for Client-Side Protection monitoring.
csp_delete_page
Delete a page and all associated scripts and policies.
csp_delete_website
Delete a website and all associated pages, scripts, and policies.
csp_get_page
Get details for a specific page.
csp_get_policy
Get details for a specific policy.
csp_get_script
Get details for a specific script.
csp_get_website
Get details for a specific website.
csp_list_header_events
List security header change events for a page.
csp_list_headers
List security headers detected on a page.
csp_list_pages
List all pages. Optionally filter by website.
csp_list_policies
List all Content Security Policies for a page.
csp_list_policy_reports
List CSP violation reports for a policy.
csp_list_scripts
List all scripts detected on a page.
csp_list_websites
List all websites configured for Client-Side Protection.
csp_update_page
Update a page’s configuration.
csp_update_policy
Update a policy’s configuration.
csp_update_script
Update a script’s authorization status or justification.
csp_update_website
Update a website’s configuration.