pub async fn get_dictionary(
configuration: &mut Configuration,
params: GetDictionaryParams,
) -> Result<DictionaryResponse, Error<GetDictionaryError>>Expand description
Retrieve a single dictionary by name for the version and service.
pub async fn get_dictionary(
configuration: &mut Configuration,
params: GetDictionaryParams,
) -> Result<DictionaryResponse, Error<GetDictionaryError>>Retrieve a single dictionary by name for the version and service.