pub async fn create_dm_routing_config(
configuration: &mut Configuration,
params: CreateDmRoutingConfigParams,
) -> Result<RoutingConfigResponse, Error<CreateDmRoutingConfigError>>Expand description
Create a new routing config. An optional initial_version may be provided to seed the config with paths and rules in a single request, and may also be activated immediately.