pub struct DeleteDmRoutingConfigParams {
pub config_id: String,
pub force: Option<bool>,
}Expand description
struct for passing parameters to the method delete_dm_routing_config
Fields
config_id: Stringforce: Option<bool>When true, allows deleting a routing config that has an active version. This is destructive — traffic routing for any paths served by the config will stop immediately.