pub struct ListDmRoutingConfigPathsParams {
pub config_id: String,
pub path: Option<String>,
pub _match: Option<String>,
pub sort: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i32>,
}Expand description
struct for passing parameters to the method list_dm_routing_config_paths
Fields
config_id: Stringpath: Option<String>Filter results by path pattern. The match strategy is controlled by the match parameter.
_match: Option<String>How to match the value of the path filter against existing path patterns. Has no effect unless path is also provided.
sort: Option<String>The order in which to list the results.
cursor: Option<String>Cursor value from the next_cursor field of a previous response, used to retrieve the next page. To request the first page, this should be empty.
limit: Option<i32>Limit how many results are returned.