pub struct ListDmRoutingConfigRulesParams {
pub config_id: String,
pub path_id: String,
pub sort: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i32>,
}Expand description
struct for passing parameters to the method list_dm_routing_config_rules
Fields
config_id: Stringpath_id: Stringsort: Option<String>The order in which to list the results.
cursor: Option<String>Cursor value from the next_cursor field of a previous response, used to retrieve the next page. To request the first page, this should be empty.
limit: Option<i32>Limit how many results are returned.