pub struct ListDmRoutingConfigsParams {
pub state: Option<Vec<String>>,
pub sort: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i32>,
}Expand description
struct for passing parameters to the method list_dm_routing_configs
Fields
state: Option<Vec<String>>Filter configs by lifecycle state. Accepts a comma-separated list of state values (e.g. ?state=active,active-with-draft). Returns only configs whose current state matches one of the provided values. Returns 400 if any value is not a recognised state.
sort: Option<String>The order in which to list the results.
cursor: Option<String>Cursor value from the next_cursor field of a previous response, used to retrieve the next page. To request the first page, this should be empty.
limit: Option<i32>Limit how many results are returned.