Module logging_endpoint_errors_api

Module logging_endpoint_errors_api 

Structs

GetLogEndpointErrorsParams
struct for passing parameters to the method get_log_endpoint_errors

Enums

GetLogEndpointErrorsError
struct for typed errors of method get_log_endpoint_errors

Functions

get_log_endpoint_errors
Provides a near real-time stream of log errors through a hybrid short-polling model. A client should make an initial request using the from parameter to specify a start time. The to parameter should be used alongside the from parameter since the default bucket is 10 seconds. For pagination, use the URLs provided in the Link header of the response. These contain updated from timestamps for retrieving the next or previous page of logs. Defaults to application/x-ndjson format. Use Accept: application/json header to request standard JSON array format instead.