pub async fn get_server_pool(
configuration: &mut Configuration,
params: GetServerPoolParams,
) -> Result<PoolResponse, Error<GetServerPoolError>>Expand description
Gets a single pool for a particular service and version.
pub async fn get_server_pool(
configuration: &mut Configuration,
params: GetServerPoolParams,
) -> Result<PoolResponse, Error<GetServerPoolError>>Gets a single pool for a particular service and version.