pub async fn list_server_pools(
configuration: &mut Configuration,
params: ListServerPoolsParams,
) -> Result<Vec<PoolResponse>, Error<ListServerPoolsError>>Expand description
Lists all pools for a particular service and pool.
pub async fn list_server_pools(
configuration: &mut Configuration,
params: ListServerPoolsParams,
) -> Result<Vec<PoolResponse>, Error<ListServerPoolsError>>Lists all pools for a particular service and pool.