pub struct AgentKey {
pub access_key: String,
pub secret_key: String,
pub is_primary: bool,
pub created_at: String,
pub updated_at: String,
}Expand description
AgentKey : An agent key used for configuring a Next-Gen WAF agent.
Fields
access_key: StringAgent configuration access key value.
secret_key: StringAgent configuration secret key value.
is_primary: boolWhether the agent key is the primary key that should be used to configure the agent.
created_at: StringDate and time the agent key was created.
updated_at: StringDate and time the agent key was last updated.
Implementations