pub struct DiscoveredOperationGet {
pub method: Method,
pub domain: String,
pub path: String,
pub status: Option<Status>,
pub updated_at: Option<String>,
pub last_seen_at: Option<String>,
}Fields
method: MethodThe HTTP method for the operation.
domain: StringThe domain for the operation.
path: StringThe path for the operation, which may include path parameters.
status: Option<Status>The current status of the operation.
updated_at: Option<String>The timestamp when the operation was last updated.
last_seen_at: Option<String>The timestamp when the operation was last seen in traffic.
Implementations