pub struct DraftDiff {
pub added: Option<Vec<PathWithRules>>,
pub deleted: Option<Vec<PathWithRules>>,
pub modified: Option<Vec<PathChange>>,
}Expand description
DraftDiff : The differences between the draft and active versions of a routing config.
Fields
added: Option<Vec<PathWithRules>>Paths that exist in the draft but not in the active version.
deleted: Option<Vec<PathWithRules>>Paths that exist in the active version but not in the draft.
modified: Option<Vec<PathChange>>Paths that exist in both versions but have changed.
Implementations