pub struct OperationGet {
pub method: Method,
pub domain: String,
pub path: String,
pub description: Option<String>,
pub tag_ids: Option<Vec<String>>,
pub id: String,
pub created_at: Option<String>,
pub updated_at: String,
pub last_seen_at: Option<String>,
}Fields
method: MethodThe HTTP method for the operation.
domain: StringThe domain for the operation.
path: StringThe path for the operation, which may include path parameters.
description: Option<String>A description of what the operation does.
tag_ids: Option<Vec<String>>An array of operation tag IDs associated with this operation.
id: StringThe unique identifier of the operation.
created_at: Option<String>The timestamp when the operation was created.
updated_at: StringThe timestamp when the operation was last updated.
last_seen_at: Option<String>The timestamp when the operation was last seen in traffic.
Implementations