pub struct OriginInspectorRealtimeEntry {
pub recorded: Option<i32>,
pub aggregated: Option<HashMap<String, OriginInspectorMeasurements>>,
pub datacenter: Option<HashMap<String, HashMap<String, OriginInspectorMeasurements>>>,
}Expand description
OriginInspectorRealtimeEntry : Each reporting period is represented by an entry in the Data property of the top level response and provides access to measurement data for that time period, grouped by origin name and optionally by POP. The datacenter property organizes the measurements by Fastly POP, while the aggregated property combines the measurements of all POPs.
Fields
recorded: Option<i32>The Unix timestamp at which this record’s data was generated.
aggregated: Option<HashMap<String, OriginInspectorMeasurements>>Groups measurements by backend name.
datacenter: Option<HashMap<String, HashMap<String, OriginInspectorMeasurements>>>Groups measurements by POP, then backend name. See the POPs API for details about POP identifiers.
Implementations
Sourceimpl OriginInspectorRealtimeEntry
impl OriginInspectorRealtimeEntry
Sourcepub fn new() -> OriginInspectorRealtimeEntry
pub fn new() -> OriginInspectorRealtimeEntry
Each reporting period is represented by an entry in the Data property of the top level response and provides access to measurement data for that time period, grouped by origin name and optionally by POP. The datacenter property organizes the measurements by Fastly POP, while the aggregated property combines the measurements of all POPs.