pub struct PaginationMeta {
pub limit: Option<i32>,
pub next_cursor: Option<String>,
pub previous_cursor: Option<String>,
pub sort: Option<String>,
}Expand description
PaginationMeta : Cursor-based pagination metadata.
Fields
limit: Option<i32>The number of records returned per page.
next_cursor: Option<String>Cursor value used to retrieve the next page of results. Empty if there are no more results.
previous_cursor: Option<String>Cursor value used to retrieve the previous page of results. Empty if there is no previous page.
sort: Option<String>The sort order applied to the results.
Implementations
Sourceimpl PaginationMeta
impl PaginationMeta
Sourcepub fn new() -> PaginationMeta
pub fn new() -> PaginationMeta
Cursor-based pagination metadata.