pub struct Position {
pub before: Option<String>,
pub after: Option<String>,
}Expand description
Position : The position at which to place a new rule. At most one of before or after may be set. Cannot be used when creating a default (empty-conditions) rule.
Fields
before: Option<String>The id of the rule that this rule should be placed before.
after: Option<String>The id of the rule that this rule should be placed after.
Implementations