pub struct RoutingConfigCondition {
pub _type: ConditionType,
pub operator: ConditionOperator,
pub key: Option<String>,
pub value: String,
}Expand description
RoutingConfigCondition : A condition that must be met for a rule to match.
Fields
_type: ConditionTypeoperator: ConditionOperatorkey: Option<String>The key to evaluate. For header conditions this is the header name. Required for header conditions.
value: StringThe value to compare against using the operator.
Implementations
Sourceimpl RoutingConfigCondition
impl RoutingConfigCondition
Sourcepub fn new(
_type: ConditionType,
operator: ConditionOperator,
value: String,
) -> RoutingConfigCondition
pub fn new( _type: ConditionType, operator: ConditionOperator, value: String, ) -> RoutingConfigCondition
A condition that must be met for a rule to match.