pub struct RuleUpdate {
pub action: Option<Box<Action>>,
pub conditions: Option<Vec<RoutingConfigCondition>>,
pub position: Option<Box<Position>>,
}Expand description
RuleUpdate : All attributes for updating a rule. At least one of action, conditions, or position must be provided.
Fields
action: Option<Box<Action>>conditions: Option<Vec<RoutingConfigCondition>>position: Option<Box<Position>>Implementations
Sourceimpl RuleUpdate
impl RuleUpdate
Sourcepub fn new() -> RuleUpdate
pub fn new() -> RuleUpdate
All attributes for updating a rule. At least one of action, conditions, or position must be provided.