pub struct SuccessfulResponseAsObject {
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub id: Option<String>,
pub fqdn: Option<String>,
pub service_id: Option<String>,
pub routing_configuration_id: Option<String>,
pub description: Option<String>,
pub activated: Option<bool>,
pub verified: Option<bool>,
}Expand description
SuccessfulResponseAsObject : All attributes for a domain response
Fields
created_at: Option<String>Date and time in ISO 8601 format.
updated_at: Option<String>Date and time in ISO 8601 format.
id: Option<String>Domain Identifier (UUID).
fqdn: Option<String>The fully-qualified domain name for your domain. Can be created, but not updated.
service_id: Option<String>The service_id associated with your domain or null if there is no association.
routing_configuration_id: Option<String>The routing_configuration_id associated with your domain or null if there is no association.
description: Option<String>A freeform descriptive note.
activated: Option<bool>Denotes if the domain has at least one TLS activation or not.
verified: Option<bool>Denotes that the customer has proven ownership over the domain by obtaining a Fastly-managed TLS certificate for it or by providing a their own TLS certificate from a publicly-trusted CA that includes the domain or matching wildcard.
Implementations
Sourceimpl SuccessfulResponseAsObject
impl SuccessfulResponseAsObject
Sourcepub fn new() -> SuccessfulResponseAsObject
pub fn new() -> SuccessfulResponseAsObject
All attributes for a domain response