pub struct TagGet {
pub name: String,
pub description: Option<String>,
pub id: String,
pub count: Option<i32>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
}Fields
name: StringThe name of the operation tag.
description: Option<String>A description of the operation tag.
id: StringThe unique identifier of the operation tag.
count: Option<i32>The number of operations associated with this operation tag.
created_at: Option<String>The date and time the operation tag was created.
updated_at: Option<String>The date and time the operation tag was last updated.
Implementations