Structs
- CspCreate
Page Params - struct for passing parameters to the method
csp_create_page - CspCreate
Policy Params - struct for passing parameters to the method
csp_create_policy - CspCreate
Website Params - struct for passing parameters to the method
csp_create_website - CspDelete
Page Params - struct for passing parameters to the method
csp_delete_page - CspDelete
Website Params - struct for passing parameters to the method
csp_delete_website - CspGet
Page Params - struct for passing parameters to the method
csp_get_page - CspGet
Policy Params - struct for passing parameters to the method
csp_get_policy - CspGet
Script Params - struct for passing parameters to the method
csp_get_script - CspGet
Website Params - struct for passing parameters to the method
csp_get_website - CspList
Header Events Params - struct for passing parameters to the method
csp_list_header_events - CspList
Headers Params - struct for passing parameters to the method
csp_list_headers - CspList
Pages Params - struct for passing parameters to the method
csp_list_pages - CspList
Policies Params - struct for passing parameters to the method
csp_list_policies - CspList
Policy Reports Params - struct for passing parameters to the method
csp_list_policy_reports - CspList
Scripts Params - struct for passing parameters to the method
csp_list_scripts - CspList
Websites Params - struct for passing parameters to the method
csp_list_websites - CspUpdate
Page Params - struct for passing parameters to the method
csp_update_page - CspUpdate
Policy Params - struct for passing parameters to the method
csp_update_policy - CspUpdate
Script Params - struct for passing parameters to the method
csp_update_script - CspUpdate
Website Params - struct for passing parameters to the method
csp_update_website
Enums
- CspCreate
Page Error - struct for typed errors of method
csp_create_page - CspCreate
Policy Error - struct for typed errors of method
csp_create_policy - CspCreate
Website Error - struct for typed errors of method
csp_create_website - CspDelete
Page Error - struct for typed errors of method
csp_delete_page - CspDelete
Website Error - struct for typed errors of method
csp_delete_website - CspGet
Page Error - struct for typed errors of method
csp_get_page - CspGet
Policy Error - struct for typed errors of method
csp_get_policy - CspGet
Script Error - struct for typed errors of method
csp_get_script - CspGet
Website Error - struct for typed errors of method
csp_get_website - CspList
Header Events Error - struct for typed errors of method
csp_list_header_events - CspList
Headers Error - struct for typed errors of method
csp_list_headers - CspList
Pages Error - struct for typed errors of method
csp_list_pages - CspList
Policies Error - struct for typed errors of method
csp_list_policies - CspList
Policy Reports Error - struct for typed errors of method
csp_list_policy_reports - CspList
Scripts Error - struct for typed errors of method
csp_list_scripts - CspList
Websites Error - struct for typed errors of method
csp_list_websites - CspUpdate
Page Error - struct for typed errors of method
csp_update_page - CspUpdate
Policy Error - struct for typed errors of method
csp_update_policy - CspUpdate
Script Error - struct for typed errors of method
csp_update_script - CspUpdate
Website Error - struct for typed errors of method
csp_update_website
Functions
- csp_
create_ page - Create a new page for monitoring.
- csp_
create_ policy - Create a new Content Security Policy for a page.
- csp_
create_ website - Create a new website for Client-Side Protection monitoring.
- csp_
delete_ page - Delete a page and all associated scripts and policies.
- csp_
delete_ website - Delete a website and all associated pages, scripts, and policies.
- csp_
get_ page - Get details for a specific page.
- csp_
get_ policy - Get details for a specific policy.
- csp_
get_ script - Get details for a specific script.
- csp_
get_ website - Get details for a specific website.
- csp_
list_ header_ events - List security header change events for a page.
- csp_
list_ headers - List security headers detected on a page.
- csp_
list_ pages - List all pages. Optionally filter by website.
- csp_
list_ policies - List all Content Security Policies for a page.
- csp_
list_ policy_ reports - List CSP violation reports for a policy.
- csp_
list_ scripts - List all scripts detected on a page.
- csp_
list_ websites - List all websites configured for Client-Side Protection.
- csp_
update_ page - Update a page’s configuration.
- csp_
update_ policy - Update a policy’s configuration.
- csp_
update_ script - Update a script’s authorization status or justification.
- csp_
update_ website - Update a website’s configuration.