create_dm_routing_config

Function create_dm_routing_config 

pub async fn create_dm_routing_config(
    configuration: &mut Configuration,
    params: CreateDmRoutingConfigParams,
) -> Result<RoutingConfigResponse, Error<CreateDmRoutingConfigError>>
Create a new routing config. An optional initial_version may be provided to seed the config with paths and rules in a single request, and may also be activated immediately.