pub async fn create_dm_routing_config_rule(
configuration: &mut Configuration,
params: CreateDmRoutingConfigRuleParams,
) -> Result<RuleResponse, Error<CreateDmRoutingConfigRuleError>>Expand description
Add a new rule to a path on the config’s draft version. If no draft exists, one is created automatically by cloning the active version. A rule with an empty conditions array is a default (catch-all) rule and there can be at most one default rule per path.